# -*- coding: utf-8 -*-

from django.contrib import admin
from django.utils.translation import ugettext as _
from django import forms

from jumbo.admin.options import ExtendibleModelAdmin
from jumbo.apps.abicab.models import Bank

### SEARCH FORM ###
STATUS = (('', '---'), ('1', _('Active')), ('0', _('Disactive')),)
class BankAdminSearchForm(forms.ModelForm):
    class Meta:
        model = Bank
        fields = ('abi', 'cab', 'zip_code', 'province', 'country')
        display_fields = (
            'status',
            ('abi', 'cab',),
            ('name__icontains', 'agency__icontains',),
            ('zip_code', 'locality__icontains',), ('province', 'country',),
        )

    def __init__(self, *args, **kws):
        super(BankAdminSearchForm, self).__init__(*args, **kws)
        self.fields['name__icontains'] = forms.CharField(label=_('Name'), required=False)
        self.fields['agency__icontains'] = forms.CharField(label=_('Agency'), required=False)
        self.fields['locality__icontains'] = forms.CharField(label=_('Locality'), required=False)
        self.fields['status'] = forms.ChoiceField(label=_("Status"), choices=STATUS, required=False)

### GENERIC ###
class BankAdmin(ExtendibleModelAdmin):
    save_on_top = True
    fieldsets = (
        (_('logs admin'), {
            'fields':('creator', 'date_create','last_modifier', 'date_last_modify',),
            'classes': ('collapse',)
        }),
        (_('general information'), {'fields':(
            'status', ('abi', 'cab',), ('name', 'agency',), 'address', 'zip_code', 'locality', 'province', 'country'
        )})
    )
    list_display = (
        'get_status_icon', 'abi', 'cab', 'name', 'agency', 'address', 'zip_code', 'locality', 'province', 'country', 'get_edit_icon', 'get_delete_icon'
    )
    search_form = BankAdminSearchForm
    search_fields = ('abi', 'cab', 'name',)

admin.site.register(Bank, BankAdmin)