from django.http import HttpResponse
from django.db.models import Q
from django.utils import simplejson
from django.utils.encoding import smart_unicode
from django.core.urlresolvers import get_callable

class AutoComplete(object):

    def __init__(self):
        self.settings = dict()


    def __call__(self, request, ac_name, query_param='q'):
        if not self.settings.get(ac_name):
            return self.not_found(ac_name)

        model, fields, limit, key, label, auth, views, force_selection = self.settings[ac_name]

        #v = get_callable(qs)
        #qs = v()

        if auth and not request.user.is_authenticated():
            return self.forbidden(ac_name)
        query = request.GET.get(query_param, '')

        # Se viene passata una vista si occupa lei di tutto. Quindi evito
        # di fare il filtro automatico, semplicemente la chiamo e metto nella
        # variabile qs il risultato tornato
        if views:
            v = get_callable(views)
            qs = v(request, query)
        else:
            qs = model.objects.filter(filter)

        if fields:
            filter = Q()
            for field in fields:
                if not '__' in field:
                    field = '%s__icontains' % field
                filter |= Q(**{field: query})
            qs = qs.filter(filter)

        qs = qs[:limit]

        if isinstance(qs, list):
            result = []
            for obj in qs:
                result.append({"id":obj[0], "name":obj[1]})
        else:
            if isinstance(label, basestring):
                if key == 'pk':
                    key = qs.model._meta.pk.attname
                result = list(qs.values_list(key, label))
            else:
                result = []
                for obj in qs:
                    result.append({"id":getattr(obj, key), "name":label(obj)})

        if not force_selection:
            result.insert(0, {"id":query, "name":query})
        return HttpResponse(simplejson.dumps(result),
                mimetype='application/json')


    def register(self, id, model=None, search_fields=(), limit=None, key='pk',
                 label=lambda obj: smart_unicode(obj), auth=False, views=None, force_selection=True):
        self.settings[id] = (model, search_fields, limit, key, label, auth, views, force_selection)

    def unregister(self,id):
        if self.settings.has_key(id):
            del self.settings[id]
        else:
            raise Exception("id %s is not registered " % id)

    def not_found(self, ac_name):
        return HttpResponse(status=404)


    def forbidden(self, ac_name):
        return HttpResponse(status=403)


autocomplete = AutoComplete()
