# -*- coding: utf-8 -*-
from datetime import datetime, time, date, timedelta
import calendar, os, os.path

from django.http import HttpResponse, HttpResponseRedirect, HttpResponseNotFound, HttpResponseForbidden
from django.utils.translation import ugettext_lazy as _
from django.utils.translation import ugettext
from django.core.urlresolvers import get_callable

from jumbo.shortcuts import render_to_response, render_to_string
from jumbo.apps.calendar.utils import CalendarYear, CalendarMonth, CalendarWeek, CalendarDay


def calendar_list(request, model, field_date_begin, field_date_end=None,
                  queryset_view = None, type_list=None, day=None,
                  template_dir=None, url_name=None, extra_context=None):
    if extra_context is None: extra_context = {}

    if model:
        queryset = model.objects.all()

    if queryset_view:
        queryset = get_callable(queryset_view)()

    # Controllo il parametro type_list, altrim default mese
    if not type_list or type_list not in ('day', 'week', 'month', 'year'):
        type_list = 'month'

    if not day:
        day = date.today()
    else:
        day = date(int(day[0:4]),int(day[4:6]),int(day[6:]))

    #model = queryset.model
    if not template_dir:
        template_dir = "calendar"

    if type_list == 'day':
        template_name = os.path.join(template_dir, 'day.html')
        queryset = queryset.filter(**{"%s__year" % field_date_begin :day.year,
                                      "%s__month" % field_date_begin : day.month,
                                      "%s__day" % field_date_begin : day.day})
        period = CalendarDay(day)

    if type_list == 'week':
        template_name = os.path.join(template_dir, 'week.html')
        queryset = queryset.filter(**{"%s__year" % field_date_begin :day.year,
                                      "%s__month" % field_date_begin : day.month})
        period = CalendarWeek(day)

    if type_list == 'month':
        template_name = os.path.join(template_dir, 'month.html')
        queryset = queryset.filter(**{"%s__year" % field_date_begin :day.year,
                                      "%s__month" % field_date_begin : day.month})
        period = CalendarMonth(day)

    if type_list == 'year':
        template_name = os.path.join(template_dir, 'year.html')
        queryset = queryset.filter(**{"%s__year" % field_date_begin :day.year})
        period = CalendarYear(day)

    for obj in queryset:
        period.add_event(obj, field_date_begin=field_date_begin, field_date_end=field_date_end)

    if not url_name:
        url_name = "admin:%s_%s_calendar" % (model._meta.app_label, model._meta.object_name.lower())

    return render_to_response(template_name, period=period, app_label=model._meta.app_label, url_name=url_name)