# -*- coding: utf-8 -*-
from django.db import models
from django.utils.translation import ugettext_lazy as _
from django.utils.translation import get_language

class Language(models.Model):
    name = models.CharField(
        max_length=20,
        verbose_name=_('full name'),
        help_text=_('full name'),
    )
    country = models.CharField(
        max_length=20,
        verbose_name=_('country'),
        help_text=_('country'),
    )
    nationality = models.CharField(
        max_length=20,
        verbose_name=_('nationality'),
        help_text=_('nationality'),
    )
    code = models.CharField(
        max_length=2,
        verbose_name=_('iso code language'),
        help_text=_('iso code language'),
    )
    def __unicode__(self):
        return self.name
    class Meta:
        ordering = ('code', 'name',)
        verbose_name = _('language')
        verbose_name_plural = _('languages')
        ordering = ('name',)

class I18NProxy(object):
    def __init__(self, tr, original):
        self._tr = tr
        self._original = original
    def __getattr__(self, name):
        attr = getattr(self._tr, name, None)
        if not attr or (attr and (attr == '' or attr == u'')):
            attr = getattr(self._original, name)
        return attr

class I18NModel(models.Model):
    class Meta:
        abstract = True
    def translate(self, language=None):
        language = language or get_language()[:2]
        try:
            return I18NProxy(self.translations.get(language__code=language), self)
        except models.ObjectDoesNotExist:
            return self

class TranslationModel(models.Model):
    language = models.ForeignKey(
        Language,
        verbose_name=_('language'),
        help_text=_('language'),
    )

    def __unicode__(self):
        return self.language.name

    class Meta:
        abstract = True
        verbose_name=_('translation')
        verbose_name_plural=_('translation')
        ordering = ('language__code',)

