# -*- coding: utf-8 -*-
'''
Created on 2/ago/2011

@author: simone cittadini
'''
from django.test import TestCase
from django.contrib.auth.models import User

from models import SCProfiles, SCProfile, SCProfileDummyUno, \
    SCProfileDummyDue
#from alara.appfortests.models import SCProfileChild

class TestRight(TestCase):
    """
    Testo i casi in cui non ci sono errori di input o nello stato del sistema.
    Errori umani in un'ottica di funzionamento standard sempre qui.
    """
    def test_funzionamento_utenti(self):
        # iniziamo senza profili
        SCProfiles.objects.all().delete()
        SCProfile.objects.all().delete()
        
        # abbiamo uno User di django
        u = User.objects.create_user('login', 'login@mail.com', 'password')
        
        # creo un SCProfile collegato
        scp = SCProfiles.objects.create(user=u)
        
        # creo un Profile specifico e lo collego al profile
        scu_dummy_uno = SCProfileDummyUno.objects.create(dummy_field='dummy',
                                                         scprofiles=scp)
        
        # esiste un'istanza generica
        self.assertEqual(1,
                         SCProfile.objects.all().count())
        
        # l'istanza sa fare un cast al modello specifico
        self.assertEqual(scu_dummy_uno,
                         SCProfile.objects.get(scprofiles=scp).as_specific())
        
        # creo un altro tipo di Profile specifico collegato allo stesso profilo
        scu_dummy_due = SCProfileDummyDue.objects.create(dummy_field=1,
                                                        scprofiles=scp)
        
        # l'istanza generica è un'altra
        self.assertEqual(2,
                         SCProfile.objects.all().count())
        
        # ma ognuno conosce il proprio profile e quindi Profile, a prescindere
        # dal cast up o down
        for scu in SCProfile.objects.all():
            self.assertEqual(scp,
                             scu.get_profiles())
            self.assertEqual(u,
                             scu.get_user())
            self.assertEqual(scp,
                             scu.as_specific().get_profiles())
            self.assertEqual(u,
                             scu.as_specific().get_user())
            
        # si può far tornare un qs automaticamente castato di tutti gli
        # utenti di un certo profilo
        qs = scp.get_profili_specifici()
#        for scu in qs:
#            self.assertIn(scu,
#                          (scu_dummy_uno, scu_dummy_due))
            
    def test_metodi_di_comodo(self):
        # per evitare errori di associazione conviene creare gli utenti
        # direttamente con i metodi di SCProfiles
        u = SCProfiles.create_user('login', 'login@mail.com', 'password')
        
        # questo user ha già un profile associato
        self.assertEqual(SCProfiles.objects.get(user=u),
                         u.scprofiles_set.all()[0])
        
        # dal profile posso aggiungere tipi Profile
        scp = SCProfiles.objects.get(user=u)
        dummyuno = scp.add_profile(SCProfileDummyUno,
                                  None,
                                  {'dummy_field' : "A"})
        self.assertEqual(dummyuno.scprofiles,
                         scp)
        self.assertEqual(dummyuno.dummy_field,
                         "A")
        
        # posso anche rimuoverli
        scp.add_profile(SCProfileDummyDue,
                          None,
                          {'dummy_field' : 1})

        scp.remove_profile(SCProfileDummyDue)
        self.assertEqual(1,
                         SCProfile.objects.filter(scprofiles__exact=scp).count())
        
#    def test_import_da_librerie_esterne(self):
        # gli utenti possono stare in librerie esterne
#        scp = SCProfiles.objects.get(
#            user=SCProfiles.create_user('login', 'login@mail.com', 'password'))
#        scp.add_profile(SCProfileChild)
        
        # non c'è bisogno di avere importato la classe , 
        # si può passare il nome come stringa a runtime
#        u = scp.add_profile("SCProfileChildNonImportarmi",
#                           "appfortests.models")
#        self.assertEqual(scp,
#                         u.scprofiles)
#        self.assertEqual("<class 'alara.appfortests.models.SCProfileChildNonImportarmi'>",
#                         str(u.__class__))
#        self.assertEqual(2,
#                         SCProfile.objects.all().count())        
#        scp.remove_profile("SCProfileChildNonImportarmi",
#                          "appfortests.models")
#        self.assertEqual(1,
#                         SCProfile.objects.all().count())
