# -*- coding: utf-8 -*-

from django.contrib.auth.decorators import login_required
from django.http import HttpResponse, HttpResponseRedirect, HttpResponseNotFound, HttpResponseForbidden
from django.utils.translation import ugettext_lazy as _
from django.views.generic import list_detail
from django.db.models import Sum

from jumbo.core.urlresolvers import reverse
from jumbo.views.generic import generic_views
from jumbo.shortcuts import render_to_response, render_to_string
from jumbo.http import HttpForbidden

from jumbo.apps.project.models import Project
from jumbo.apps.project.forms import ProjectForm, ProjectSearchForm
from jumbo.apps.project.list import ProjectList

@login_required
def project_list(request):
    if not request.user.has_perm("project.can_view_projects"):
        return HttpResponseForbidden(render_to_string('jumbo/forbidden.html'))

    if request.GET:
        search_form = ProjectSearchForm(request.GET)
    else:
        search_form = ProjectSearchForm()

    qs = generic_views.get_query_set(ProjectList, search_form)

    data_list = ProjectList()

    return list_detail.object_list(
        request,
        qs,
        paginate_by=20,
        template_name='project/project_list.html',
        #extra_context={'search_form':search_form, 'data_list':data_list},
        extra_context={'data_list':data_list},
    )

@login_required
def project_view(request, project_id=None, template_name='project/project_form.html'):
    if not request.user.has_perm("project.add_project") and \
       not request.user.has_perm("project.change_project"):
        return HttpForbidden()

    if  project_id == None:
        project = Project()
        title_form = _('Add Project')
    else:
        project = Project.objects.get(pk = project_id)
        title_form = _('Change Project')

    if request.method == 'POST':
        form = ProjectForm(request.POST, instance=project)

        if form.is_valid():
            form.save()
            if '_save' in request.POST:
                return HttpResponseRedirect(reverse('project-project-list'))
            if '_save_continue' in request.POST:
                return HttpResponseRedirect(reverse('project-project-edit', form.instance.id))
            if '_save_add_another' in request.POST:
                return HttpResponseRedirect(reverse('project-project-add'))
    else:
        form = ProjectForm(instance=project)

    return render_to_response(template_name, form=form, title_form=title_form)

@login_required
def total_invoicerows(request, project_id):
    try:
        project = Project.objects.get(pk=project_id)
    except Exception, e:
        return render_to_response('jumbo/generic_error.html', error=str(e),
                                  is_popup=True, is_ajax=True)

    qs_cus = project.invoicerows.filter(store_cause__category="cus")
    qs_sup = project.invoicerows.filter(store_cause__category="sup")
    return render_to_response('project/project_total_invoicerows.html', qs_cus=qs_cus, qs_sup=qs_sup, project=project)

