from django import forms
from django.forms.widgets import Select
from django.utils.safestring import mark_safe
from django.forms.util import flatatt
from jumbo.apps.provinceitaliane.models import Region, Province

class RegioneLinkToProvinceWidget(Select):
    def render(self, name, value, attrs=None, choices=()):
        js = """
            <script type="text/javascript">
                jQuery(document).ready(function($) {
                    $("select#id_%(regionefield)s").change(function(){
                        Dajaxice.jumbo.apps.provinceitaliane.get_province_italiane(Dajax.process, {'regione_id': $(this).val()});
                    });
                });
            </script>
        """ % {'regionefield':name}
        output = super(RegioneLinkToProvinceWidget, self).render(name, value, attrs=attrs, choices=choices)
        output += js
        return mark_safe(output)

class RegionLinkToProvince(forms.ModelChoiceField):
    """
    A ModelChoiceField
    """
    widget = RegioneLinkToProvinceWidget

    def __init__(self, empty_label=u"---------", cache_choices=False,
                 required=True, widget=None, label=None, initial=None,
                 help_text=None, to_field_name=None, *args, **kwargs):

        queryset = Region.objects.all()
        super(RegionLinkToProvince, self).__init__(queryset, empty_label=empty_label,
                                                    cache_choices=cache_choices, required=required,
                                                    widget=widget, label=label, initial=initial,
                                                    help_text=help_text, to_field_name=to_field_name,
                                                    *args, **kwargs)

# Ho creato un ProvinceChoiceField per bypassare il controllo
# sulla validita delle scelte e fare solo quello sul controllo che il valore sia
# presente
class ProvinceWidget(Select):
    def render(self, name, value, attrs=None, choices=()):
        if value is None: value = ''
        final_attrs = self.build_attrs(attrs, name=name)
        output = [u'<select%s>' % flatatt(final_attrs)]

        if not value:
            output.append("<option value=''></option>")
        else:
            sel_p = Province.objects.get(id=value)
            p = Province.objects.filter(region__id=sel_p.region.id)
            for provincia in p:
                selected = ""
                if str(provincia.id) == str(value):
                    selected = " selected"
                output.append("<option value='%s'%s>%s</option>" % (provincia.id, selected, provincia.name))

        output.append(u'</select>')
        return mark_safe(u'\n'.join(output))

class ProvinceChoiceField(forms.ChoiceField):
    widget = ProvinceWidget

    def __init__(self, choices=(), required=True, widget=None, label=None,
                 initial=None, help_text=None, *args, **kwargs):
        super(ProvinceChoiceField, self).__init__(choices=choices, required=required,
                                                  widget=widget, label=label,
                                                  initial=initial, help_text=help_text,
                                                  *args, **kwargs)

    def to_python(self, value):
        try:
            value = Province.objects.get(**{'pk': value or None})
        except Province.DoesNotExist:
            raise forms.ValidationError(self.error_messages['invalid_choice'] % {'value': value})
        return value

    def validate(self, value):
        """
        Validates that the input is in self.choices.
        """
        if not value:
            raise forms.ValidationError(self.error_messages['invalid_choice'] % {'value': value})
