from django.conf import settings
from django.forms.widgets import Select
from django.core.urlresolvers import reverse, get_callable
from django.utils.safestring import mark_safe
from django.db.models import get_model
from jumbo.middleware.thread_local import get_request

class ChainedSelect(Select):
    def __init__(self, queryset, choices, app_name, model_name, chain_field, model_field, chain_function=None, 
                       chained_default_field='default', is_required=False, *args, **kwargs):
        self.app_name = app_name
        self.model_name = model_name
        self.chain_field = chain_field
        self.model_field = model_field
        self.chain_function = chain_function
        self.chained_default_field = chained_default_field
        self.queryset = queryset
        self.choices = choices

        if is_required:
            self.is_required = "true"
        else:
            self.is_required = "false"
        super(Select, self).__init__(*args, **kwargs)


    def render(self, name, value, attrs=None, choices=()):
        request = get_request()
        if self.chain_function:
            url = "/".join(reverse("function_chained_filter", kwargs={'app':self.app_name,'model':self.model_name,
                                                                      'field':self.model_field,'value':"1",
                                                                      'function':self.chain_function}).split("/")[:-2])
        else:
            url = "/".join(reverse("chained_filter", kwargs={'app':self.app_name,'model':self.model_name,
                                                             'field':self.model_field, 'default_field': self.chained_default_field,
                                                             'value':"1"}).split("/")[:-2])

        js = """
        <script type="text/javascript">
        jQuery(document).ready(function($) {
            var start_value = $("select#id_%(chainfield)s")[0].value;
            var field_value = '%(field_value)s';
            if($("#%(id)s")[0].value == "" && start_value != ""){
                $.getJSON("%(url)s/"+start_value+"/", function(j){
                    var options = '';
                    if (!%(is_required)s) {
                        options += '<option value="">---------</option>';
                    }
                    for (var i = 0; i < j.length; i++) {
                        if (field_value != 'None' && field_value == j[i].value) {
                            options += '<option value="' + j[i].value + '" selected="selected">' + j[i].display + '</option>';
                        }
                        else {
                            options += '<option value="' + j[i].value + '">' + j[i].display + '</option>';
                        }
                    }
                    $("#%(id)s").html(options);
                    if (field_value == 'None') {
                        $('#%(id)s option:first').attr('selected', 'selected');
                    }
                })
            }
            $("select#id_%(chainfield)s").change(function(){
                if(!$(this).val()){
                    $("#%(id)s").html('<option value="">---------</option>');
                }
                else{
                    $.getJSON("%(url)s/"+$(this).val()+"/", function(j){
                        var has_default = false;
                        var options = '';
                        if (!%(is_required)s) {
                            options += '<option value="">---------</option>';
                        }
                        for (var i = 0; i < j.length; i++) {
                            if (j[i].is_default) {
                                options += '<option value="' + j[i].value + '" selected="selected">' + j[i].display + '</option>';
                                has_default = true;
                            }
                            else {
                                options += '<option value="' + j[i].value + '">' + j[i].display + '</option>';
                            }
                        }
                        $("#%(id)s").html(options);
                        if (!has_default) {
                            $('#%(id)s option:first').attr('selected', 'selected');
                        }
                    })
                }
            })
        })
        </script>
        
        """ % {"chainfield":self.chain_field, "url":url, "id":attrs['id'], 'field_value':value,
               "is_required" : self.is_required}
        final_choices=[]
        if value:
            item = self.queryset.filter(pk=value)[0]
            if self.chain_function:
                #f = get_callable(self.chain_function)
                filtered = [] #f(request, self.app_name, self.model_name, self.model_field, pk)
            else:
                pk = getattr(item, self.model_field+"_id")
                filter={self.model_field:pk}
                filtered = get_model( self.app_name, self.model_name).objects.filter(**filter)
            for choice in filtered:
                final_choices.append((choice.pk, unicode(choice)))
        for choice in self.choices:
            self.choices = [choice]
            break
        output = super(ChainedSelect, self).render(name, value, attrs, choices=final_choices)
        output += js
        return mark_safe(output)
