from django.contrib import admin
from django.utils.translation import ugettext_lazy as _

from jumbo.forms.models import AdminModelForm
from jumbo.apps.template.models import Template, TemplateTranslation

class TemplateTranslationForm(AdminModelForm):
    class Meta:
        model = TemplateTranslation
class TemplateTranslationInline(admin.TabularInline):
    class Meta:
        verbose_name = _('template')
        verbose_name_plural = _('templates')
    model = TemplateTranslation
    extra = 2
    form = TemplateTranslationForm
    ordering = ('language',)
    fields = ('language','title','text','meta_keywords', 'meta_description')

class TemplateForm(AdminModelForm):
    class Meta:
        model = Template
class TemplateAdmin(admin.ModelAdmin):
    save_on_top = True
    form = TemplateForm
    inlines = (TemplateTranslationInline,)
    fieldsets = (
        (_('Base template'), {'fields': ('name', 'slug', 'description', 'meta_keywords', 'meta_description', 'active', 'default',),}),
    )
    list_display = ('name', 'description', 'active',)
    list_editable = ('active',)
    list_display_link = ('name',)
    ordering = ('name',)

admin.site.register(Template, TemplateAdmin)

