import os, os.path
from django.core.urlresolvers import reverse
from django.utils.translation import ugettext as _
from django.conf import settings
from django.utils.importlib import import_module
from admin_tools.menu import items, Menu
from jumbo.middleware.thread_local import get_current_user

def get_contract_menu():
    """
    Returns the admin menu defined by the user or the default one.
    """
    menu_cls = getattr(
        settings,
        'ADMIN_CONTRACT_MENU',
        'admin_tools.menu.DefaultMenu'
    )
    mod, inst = menu_cls.rsplit('.', 1)
    mod = import_module(mod)
    return getattr(mod, inst)()


class JumboContractMenu(Menu):
    def __init__(self, **kwargs):
        Menu.__init__(self, **kwargs)

        user = get_current_user()
        if not user.is_staff:
            return None

        # Menu che saranno sempre presenti
        self.children += [
            items.MenuItem(_('Dashboard'), reverse('admin:index')),
        ]
        # -----
        for module in settings.INSTALLED_APPS:
            mm = "%s.jmenu" % module
            try:
                menu_module = import_module(mm)
                if hasattr(menu_module, 'get_root_menu'):
                    menu_module.get_root_menu(self.children)
                else:
                    # Se l'applicazione e' stata deregistrata dall'admin non visualizzo il menu, altirmenti mi darebbe
                    # errore perche non trova gli url
                    #if get_model("organization", "organization") in admin.site._registry
                    if user.has_perm("%s.view_%s" % (module, module)) or user.has_perm("%s.view_%s_%s" % (module, 'customer', module)) or user.has_perm("%s.view_%s_%s" % (module, 'supplier', module)):
                        self.children.append(items.MenuItem(
                            title=_(module.capitalize()),
                            url = reverse('admin:%s_%s_changelist' % (module, module))
                        ))
            except ImportError:
                continue

    def init_with_context(self, context):
        """
        Use this method if you need to access the request context.
        """
        return super(JumboContractMenu, self).init_with_context(context)

