# -*- coding: utf-8 -*-

# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
#  1. Redistributions of source code must retain the above copyright notice,
#     this list of conditions and the following disclaimer.
#  2. Redistributions in binary form must reproduce the above copyright
#     notice, this list of conditions and the following disclaimer in the
#     documentation and/or other materials provided with the distribution.
#  3. If the binary program depends on a modified version of this package,
#     you are encouraged to publicly release the modified version of this
#     package.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.

# adapted from satchmo/shop/management/command/delete_all_dbs.py
# rewritten the PostgreSQL postgresql_psycopg2 part
# and print some useful information on console

import os
from django.core.management.base import NoArgsCommand
from django.utils.translation import ugettext as _

def module_to_dict(module, omittable=lambda k: k.startswith('_')):
    "Converts a module namespace to a Python dictionary. Used by get_settings_diff."
    return dict([(k, repr(v)) for k, v in module.__dict__.items() if not omittable(k)])

class Command(NoArgsCommand):
    help = "Delete all databases! Be careful about using this!"

    def handle_noargs(self, **options):
        """Delete the old database."""
        from django.conf import settings
        # Because settings are imported lazily, we need to explicitly load them.
        settings._setup()
        engine = settings.DATABASE_ENGINE
        user_settings = module_to_dict(settings._wrapped)
        #engine = user_settings['DATABASE_ENGINE']
        db_host = user_settings['DATABASE_HOST']
        db_port = user_settings['DATABASE_PORT']
        db_pass = user_settings['DATABASE_PASSWORD']
        db_name = user_settings['DATABASE_NAME']
        db_user = user_settings['DATABASE_USER']
        db_dict = {'database': settings.DATABASE_NAME}

        if engine == 'sqlite3':
            try:
                os.unlink(db_name)
            except OSError, e:
                print '%s' % e
        elif engine == 'mysql':
            import _mysql
            s = _mysql.connect(host=db_host[1:-1],
                               user=db_user[1:-1],
                               passwd=db_pass[1:-1])
            print _(u"Dropping database %(database)s...") % db_dict
            s.query('drop database if exists %s' % db_name[1:-1])
            print _(u"done")
            print _(u"Creating database %(database)s...") % db_dict
            s.query('create database %s CHARACTER SET utf8 COLLATE utf8_general_ci' % db_name[1:-1])
            print _(u"done")
        elif engine == "postgresql_psycopg2":
            import psycopg2 as pg
            if db_name == '':
                raise AssertionError("You must specify a value for DATABASE_NAME in local_settings.py.")
            if db_user == '':
                raise AssertionError("You must specify a value for DATABASE_USER in local_settings.py.")
            conn_string = "dbname=template1"
            if settings.DATABASE_USER:
                conn_string = "user=%s %s" % (settings.DATABASE_USER, conn_string)
            if settings.DATABASE_PASSWORD:
                conn_string += " password='%s'" % settings.DATABASE_PASSWORD
            if settings.DATABASE_HOST:
                conn_string += " host=%s" % settings.DATABASE_HOST
            if settings.DATABASE_PORT:
                conn_string += " port=%s" % settings.DATABASE_PORT

            connection = pg.connect(conn_string)
            connection.set_isolation_level(0)
            connection.set_client_encoding('UTF8')

            db = connection.cursor()

            try:
                print _(u"Dropping database %(database)s...") % db_dict
                db.execute("DROP DATABASE %s" % settings.DATABASE_NAME)
                print _(u"done")
            except Exception, e:
                print _(u"no database found, going on")

            try:
                print _(u"Creating database %(database)s...") % db_dict
                db.execute("CREATE DATABASE %s OWNER %s ENCODING 'UTF8'" % (settings.DATABASE_NAME, settings.DATABASE_USER,))
                print _(u"done")
            except Exception, e:
                print e

            db.close()
            connection.close()
        elif engine == "postgresql":
            if db_name == '':
                raise AssertionError("You must specify a value for DATABASE_NAME in local_settings.py.")
            if db_user == '':
                raise AssertionError("You must specify a value for DATABASE_USER in local_settings.py.")
            params=" --username=%s" % db_user
            if db_host:
                params += " --host=%s" % db_host
            if db_port:
                params += " --port=%s" % db_port
            params += " %s" % db_name
            print _(u"Dropping database %(database)s...") % db_dict
            os.system('dropdb %s' % params)
            print _(u"Creating database %(database)s...") % db_dict
            os.system('createdb %s' % params)
        else:
            raise AssertionError("Unknown database engine %s" % engine)

