from django.conf import settings
from django.http import HttpResponse
from django.core.urlresolvers import resolve

from jumbo.shortcuts import render_to_response

class MaintenanceMiddleware(object):
    def process_request(self, request):
        site_maintenance = getattr(settings, 'SITE_MAINTENANCE', False)
        disable_for_superuser = getattr(settings, 'SITE_MAINTENANCE_DISABLE_FOR_SUPERUSER', False)
        disable_for_users = getattr(settings, 'SITE_MAINTENANCE_DISABLE_FOR_USERS', [])

        if not site_maintenance:
            return None

        if request.user.is_superuser and disable_for_superuser:
            return None

        if request.user.username in (disable_for_users):
            return None

        # Evito di redigere a 503 gli static
        if request.path.startswith(settings.MEDIA_URL):
            return None

        try:
            view, args, kwargs = resolve(request.path)
        except Exception:
            return None

        if 'django.contrib.admin' not in view.__module__:
            template = render_to_response('503.html')
            return HttpResponse(template, status=503)
        else:
            return None