# taken from http://trbs.net/blog/2008/09/19/django-tabbed-admin/

from django import template
from django.conf import settings

register = template.Library()

ADMIN_TABS_DEFAULT_NAME = "Main"

class GetTabListNode(template.Node):
    def __init__(self, app_list, tab_list_name):
        self.app_list = app_list
        self.tab_list_name = tab_list_name
	
    def render(self, context):
        app_list = template.resolve_variable(self.app_list, context)
        default_name = getattr(settings, "ADMIN_TABS_DEFAULT_NAME", ADMIN_TABS_DEFAULT_NAME)
        if not hasattr(settings, 'ADMIN_TABS'):
            context[self.tab_list_name] = ((default_name, app_list),)
            return ''
        tab_map = dict((k,[]) for k,v in settings.ADMIN_TABS)
        tab_map[default_name]=[]
        for app in app_list:
            for admin_tab, want_apps in settings.ADMIN_TABS:
                if app['app_url'] in want_apps:
                    tab_map[admin_tab].append(app)
                    break
            else:
                tab_map[default_name].append(app)
        tab_list = []
        if default_name not in settings.ADMIN_TABS:
            default_tab = tab_map.pop(default_name)
            if default_tab and not getattr(settings, 'ADMIN_TABS_NO_MAIN', False):
                tab_list.append((default_name, default_tab))
        for k,v in settings.ADMIN_TABS:
            if tab_map[k]==[]:
                continue
            tab_list.append((k, tab_map.pop(k)))
        context[self.tab_list_name] = tab_list
        return ''


@register.tag
def get_tab_list(parser, token):
    args = token.split_contents()
    if len(args) != 5:
        raise template.TemplateSyntaxError(
            "'%s' statement requires the form {% get_tab_list for app_list as tab_list %}." % (
                args[0], args[0]))
    return GetTabListNode(args[2], args[4])

