# -*- coding: utf-8 -*-
## utilizzato con filebrowser e serve per listare i file all'interno del sito

import os
import datetime

from django import template
from django.conf import settings
from django.db.models import Q
from django.utils.importlib import import_module

from filebrowser.settings import MEDIA_ROOT, MEDIA_URL, DIRECTORY

register = template.Library()

class File:
    def __init__(self, abs_path, url_path, name):
        self.name = name.rstrip("/")
        self.title = name.split(".")[0].replace("_", " ")
        self.abs_path = abs_path
        self.url_path = url_path
        self.is_file = True
        self.is_dir = False
        self.ext = name.split(".")[-1]

class Directory:
    def __init__(self, abs_path, url_path, name):
        self.name = name
        self.title = name.split(".")[0].replace("_", " ")
        self.abs_path = os.path.join(abs_path, name)
        self.url_path = os.path.join(url_path, name)
        self.tree = self.get_tree()
        self.is_file = False
        self.is_dir = True

    def get_tree(self):
        tree = []
        try:
            listdir = os.listdir(self.abs_path)
            for obj in listdir:
                if os.path.isfile(os.path.join(self.abs_path, obj)):
                    filE = File(self.abs_path, self.url_path, obj)
                    tree.append(filE)

                if os.path.isdir(os.path.join(self.abs_path, obj)):
                    dir_path = os.path.join(self.abs_path, obj)
                    directory = Directory(self.abs_path, self.url_path, obj)
                    tree.append(directory)
            return tree
        except:
            return tree

@register.inclusion_tag('filebrowser/tags/list_files.html', takes_context=True)
def list_files(context, path):
    path = path.rstrip("/")
    path = os.path.split(path)
    obj = path[1]
    abs_path = os.path.join(MEDIA_ROOT, DIRECTORY, path[0])
    url_path = os.path.join(MEDIA_URL, DIRECTORY, path[0])
    context['files'] = Directory(abs_path, url_path, obj)
    return context

