from django import template
from django.forms.util import flatatt
from jumbo.shortcuts import render_to_string

register = template.Library()

class Field(object):
    field = None
    width = 0

class HtmlDivNode(template.Node):
    def __init__(self, args):
        self.args = []
        num_obj_for_row = len(args)
        for item in args:
            f = Field()
            f.field = template.Variable(item)
            f.width = 100 / num_obj_for_row - 5
            self.args.append(f)

    def render(self, context):
        fields = []
        for item in self.args:
            item.field = item.field.resolve(context)
            fields.append(item)

        return render_to_string("jumbo/tags/div_form.html", fields=fields)

@register.tag
def div_form(parser, token):
    args = token.split_contents()
    if len(args) < 1:
        raise TemplateSyntaxError, "'div_form' takes at least one argument"
    return HtmlDivNode(args[1:])

@register.inclusion_tag("jumbo/tags/field.html")
def field(field):
    attrs = field.field.widget.attrs

    if field.errors:
        cssclass = 'error'
        currentclass = attrs.get('class', '')
        if currentclass:
            cssclass = "%s %s" % (cssclass, currentclass)
        attrs.update({'class':cssclass})

    if field.field.required:
        cssclass = 'required'
        currentclass = attrs.get('class', '')
        if currentclass:
            cssclass = "%s %s" % (cssclass, currentclass)
        attrs.update({'class':cssclass})

    field.field.widget.attrs = attrs
    return {'field': field}
