from django.template import Library
from django.utils.safestring import mark_safe

register = Library()

DOT = '.'

def paginator_number(i, page_num, search_params):
    if i == DOT:
        return mark_safe(u'<span>...</span>')
    elif i == page_num:
        return mark_safe(u'<span>%s</span>' % i)
    else:
        return mark_safe(u'<a href="?page=%(page)s&%(params)s" title=%(page)s>%(page)d</a> ' % {'page':i, 'params':search_params})
paginator_number = register.simple_tag(paginator_number)


@register.inclusion_tag("jumbo/tags/pagination.html", takes_context=True)
def pagination(context, paginator, page_num):
    get = context['request'].GET.copy()
    if get.has_key('page'):
        del get['page']
    context['search_params'] = get.urlencode()

    ON_EACH_SIDE = 3
    ON_ENDS = 2

    # If there are 10 or fewer pages, display links to every page.
    # Otherwise, do some fancy
    if paginator.num_pages <= 10:
        page_range = range(1, paginator.num_pages + 1)
    else:
        # Insert "smart" pagination links, so that there are always ON_ENDS
        # links at either end of the list of pages, and there are always
        # ON_EACH_SIDE links at either end of the "current page" link.
        page_range = []
        if page_num > (ON_EACH_SIDE + ON_ENDS):
            page_range.extend(range(1, ON_EACH_SIDE - 1))
            page_range.append(DOT)
            page_range.extend(range(page_num - ON_EACH_SIDE, page_num + 1))
        else:
            page_range.extend(range(1, page_num + 1))
        if page_num < (paginator.num_pages - ON_EACH_SIDE - ON_ENDS - 1):
            page_range.extend(range(page_num + 1, page_num + ON_EACH_SIDE + 1))
            page_range.append(DOT)
            page_range.extend(range(paginator.num_pages - ON_ENDS, paginator.num_pages+1))
        else:
            page_range.extend(range(page_num + 1, paginator.num_pages+1))

    context['page_range'] = page_range
    return context
