from django.template import loader
from django.http import Http404, HttpResponse, HttpResponseRedirect
from django.core.urlresolvers import reverse
from django.utils.translation import ugettext
from django.views.generic.create_update import create_object as django_create_object
from django.views.generic.create_update import update_object as django_update_object

from jumbo.http import HttpForbidden

TITLE_SAVE = ugettext('Save')
TITLE_SAVE_CONTINUE = ugettext('Save and continue editing')
TITLE_SAVE_ADD_ANOTHER = ugettext('Save and add another')

TITLE_CLONE = ugettext('Clone')
TITLE_CLONE_CONTINUE = ugettext('Clone and continue editing')
TITLE_CLONE_ADD_ANOTHER = ugettext('Clone and add another')

def create_object(request, model=None, template_name=None,
        template_loader=loader, extra_context=None,
        post_save_redirect=None, post_save_continue_redirect=None, post_save_add_another=None,
        login_required=False, context_processors=None, form_class=None):
    """
    Generic object-creation function.

    Templates: ``<app_label>/<model_name>_form.html``
    Context:
        form
            the form for the object
    """
    model_name = ugettext(model._meta.verbose_name)
    ec = {
        'title_form': ugettext('Add %s' % model_name),
        'title_save': TITLE_SAVE,
        'title_save_continue': TITLE_SAVE_CONTINUE,
        'title_save_add_another': TITLE_SAVE_ADD_ANOTHER
    }

    if '_save' in request.POST:
        try:
            post_save_redirect = reverse(post_save_redirect)
        except:
            post_save_redirect = post_save_redirect
    if '_save_continue' in request.POST:
        try:
            post_save_redirect = reverse(post_save_continue_redirect)
        except:
            post_save_redirect = post_save_continue_redirect
    if '_save_add_another' in request.POST:
        try:
            post_save_redirect = reverse(post_save_add_another)
        except:
            post_save_redirect = post_save_add_another

    if extra_context:
        ec.update(extra_context)

    return django_create_object(
        extra_context=ec,
        request=request, model=model, template_name=template_name,
        template_loader=template_loader, post_save_redirect=post_save_redirect,
        login_required=login_required, context_processors=context_processors, form_class=form_class
    )

def update_object(request, model=None, object_id=None, slug=None,
        slug_field='slug', template_name=None, template_loader=loader, extra_context=None,
        post_save_redirect=None, post_save_continue_redirect=None, post_save_add_another=None,
        login_required=False, context_processors=None, template_object_name='object',
        form_class=None):

    """
    Generic object-creation function.

    Templates: ``<app_label>/<model_name>_form.html``
    Context:
        form
            the form for the object
    """
    model_name = ugettext(model._meta.verbose_name)
    ec = {
        'title_form': ugettext('Change %s' % model_name),
        'title_save': TITLE_SAVE,
        'title_save_continue': TITLE_SAVE_CONTINUE,
        'title_save_add_another': TITLE_SAVE_ADD_ANOTHER
    }

    if '_save' in request.POST:
        try:
            post_save_redirect = reverse(post_save_redirect)
        except:
            post_save_redirect = post_save_redirect
    if '_save_continue' in request.POST:
        try:
            post_save_redirect = reverse(post_save_continue_redirect, object_id)
        except:
            post_save_redirect = post_save_continue_redirect
    if '_save_add_another' in request.POST:
        try:
            post_save_redirect = reverse(post_save_add_another)
        except:
            post_save_redirect = post_save_add_another

    if extra_context:
        ec.update(extra_context)

    return django_update_object(
        extra_context=ec,
        request=request, model=model, object_id=object_id, slug=slug,
        slug_field=slug_field, template_name=template_name,
        template_loader=template_loader, post_save_redirect=post_save_redirect,
        login_required=login_required, context_processors=context_processors, 
        template_object_name=template_object_name, form_class=form_class
    )
