from django import http
from django.template import Context, RequestContext, loader
from django.conf import settings

def server_error(request, template_name='admin/500.html'):
    """
    500 error handler.

    Templates: `500.html`
    Context: None
    """

    # Con questo piccolo if (anche se non e' pulitissima come cosa, ma noi usiamo
    # sempre admin per gli url dell'admin) riesco a dividere la grafica del template
    # 500 per la parte di admin  e quella di frontend
    # Template di admin : admin/500.html
    # Template frontend : 500.html
    if not request.path.startswith('/admin/'):
        template_name = '500.html'

    t = loader.get_template(template_name) # You need to create a 500.html template.
    return http.HttpResponseServerError(t.render(RequestContext(request, {
        'request_path': request.path,
        'MEDIA_URL': settings.MEDIA_URL,
        'ADMIN_MEDIA_PREFIX': settings.ADMIN_MEDIA_PREFIX,
    })))

def page_not_found(request, template_name='admin/404.html'):
    """
    404 error handler.

    Templates: `404.html`
    Context:
        request_path
            The path of the requested URL (e.g., '/app/pages/bad_page/')
    """

    # Con questo piccolo if (anche se non e' pulitissima come cosa, ma noi usiamo
    # sempre admin per gli url dell'admin) riesco a dividere la grafica del template
    # 404 per la parte di admin  e quella di frontend
    # Template di admin : admin/404.html
    # Template frontend : 404.html
    if not request.path.startswith('/admin/'):
        template_name = '404.html'

    t = loader.get_template(template_name) # You need to create a 404.html template.
    return http.HttpResponseNotFound(t.render(RequestContext(request, {
        'request_path': request.path,
        'MEDIA_URL': settings.MEDIA_URL,
        'ADMIN_MEDIA_PREFIX': settings.ADMIN_MEDIA_PREFIX,
    })))
